<?php
// ----------------------------------------------------------------------
// POST-NUKE Content Management System
// Copyright (C) 2002 by the PostNuke Development Team.
// http://www.postnuke.com/
// ----------------------------------------------------------------------
// Based on:
// PHP-NUKE Web Portal System - http://phpnuke.org/
// Thatware - http://thatware.org/
// ----------------------------------------------------------------------
// LICENSE
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License (GPL)
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WIthOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// To read the license please visit http://www.gnu.org/copyleft/gpl.html
// ----------------------------------------------------------------------

/**
 * get the user-specific preferences
 * @returns array
 * @return array of preferences for the specified user
 */
function time_temperature_userapi_getprefs($args) {
  extract($args);
  if (!isset($userid)) {
    $userid = 0;
  }

  // Get datbase setup - note that both pnDBGetConn() and pnDBGetTables()
  // return arrays but we handle them differently.  For pnDBGetConn() we
  // currently just want the first item, which is the official database
  // handle.  For pnDBGetTables() we want to keep the entire tables array
  // together for easy reference later on
  list($dbconn) = pnDBGetConn();
  $pntable = pnDBGetTables();

  // It's good practice to name the table and column definitions you are
  // getting - $table and $column don't cut it in more complex modules
  $prefstable = $pntable['time_temperature_user'];
  $prefscolumn = &$pntable['time_temperature_user_column'];

  // Get items - the formatting here is not mandatory, but it does make the
  // SQL statement relatively easy to read.  Also, separating out the sql
  // statement from the SelectLimit() command allows for simpler debug
  // operation if it is ever needed
  $sql = "SELECT $prefscolumn[uid],
                 $prefscolumn[zipcode]
          FROM $prefstable
          WHERE $prefscolumn[id]='$userid'";
  $result = $dbconn->Execute($sql);

  // if there was an error, grab the defaults instead...
  if ($dbconn->ErrorNo() != 0) {
    pnSessionSetVar('errormsg', _GETFAILED);
    return false;
  }
  list($id, $zipcode) = $result->fields;

  // if the accid is empty, there must be no user preferences saved - we'll load the
  // defaults...
  if (empty($zipcode)) {
    $zipcode = ""; // MUA HA HA OUR DEFAULT!
  }

  // Put items into result array.  Note that each item is checked
  // individually to ensure that the user is allowed access to it before it
  // is added to the results array
//    if (pnSecAuthAction(0, 'Weather::', "$name::$tid", ACCESS_READ)) {
  $prefs = array('id' => $id,
                 'zipcode' => $zipcode);

  // All successful database queries produce a result set, and that result
  // set should be closed when it has been finished with
  $result->Close();

  // Return the items
  return $prefs;

}

/**
 * saves the settings / preferences for a user
 * @param $args['n_accid'] the new accid preference / setting to save
 * @param $args['n_tpc'] the new tpc preference / setting to save
 * @param $args['n_tps'] the new tps preference / setting to save
 * @param $args['uid'] the user id of the user to save the preferences / settings for
 * @return true on success, false otherwise
 */
function time_temperature_userapi_savesettings($args) {

  extract($args);

  // Argument check - make sure that all required arguments are present, if
  // not then set an appropriate error message and return
  if (!isset($userid) || !isset($zipcode)) {
    pnSessionSetVar('errormsg', _MODARGSERROR);
    return false;
  }

  // Get datbase setup - note that both pnDBGetConn() and pnDBGetTables()
  // return arrays but we handle them differently.  For pnDBGetConn() we
  // currently just want the first item, which is the official database
  // handle.  For pnDBGetTables() we want to keep the entire tables array
  // together for easy reference later on
  list($dbconn) = pnDBGetConn();
  $pntable = pnDBGetTables();

  // It's good practice to name the table and column definitions you are
  // getting - $table and $column don't cut it in more complex modules
  $usertable = $pntable['time_temperature_user'];
  $usercolumn = &$pntable['time_temperature_user_column'];

  $sql = "SELECT $usercolumn[uid]
          FROM $usertable
          WHERE $usercolumn[uid]=$userid";
  $result = $dbconn->Execute($sql);

  if ($dbconn->ErrorNo() != 0) {
    pnSessionSetVar('errormsg', _GETFAILED);
    return false;
  }

list($id) = $result->fields;

  if (!$id) {
    $sql = "INSERT INTO $usertable
            ($usercolumn[uid],
             $usercolumn[zipcode])
            VALUES
            (". pnVarPrepForStore($userid) .",".
            "'". pnVarPrepForStore($zipcode) ."')";
    $errmsg = _DBINSERTERROR;
  } else {
    $sql = "UPDATE $usertable
            SET $usercolumn[zipcode]='". pnVarPrepForStore($zipcode) ."'
            WHERE $usercolumn[uid]='". pnVarPrepForStore($userid) ."'";
    $errmsg = _DBUPDATEERROR;
  }

  $result = $dbconn->Execute($sql);

  if ($dbconn->ErrorNo() != 0) {
    pnSessionSetVar('errormsg', $errmsg);
    return false;
  } else {
    return true;
  }

}

?>
